@@ -60,7 +60,7 @@ class Exceptions:
 
 class AppConfigClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html)
     """
 
@@ -76,18 +76,18 @@ class AppConfigClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#can_paginate)
         """
 
     def create_application(
-        self, *, Name: str, Description: str = None, Tags: Mapping[str, str] = None
+        self, *, Name: str, Description: str = ..., Tags: Mapping[str, str] = ...
     ) -> ApplicationResponseMetadataTypeDef:
         """
         An application in AppConfig is a logical unit of code that provides capabilities
         for your customers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.create_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.create_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_application)
         """
 
@@ -97,15 +97,15 @@ class AppConfigClient(BaseClient):
         ApplicationId: str,
         Name: str,
         LocationUri: str,
-        Description: str = None,
-        RetrievalRoleArn: str = None,
-        Validators: Sequence["ValidatorTypeDef"] = None,
-        Tags: Mapping[str, str] = None
+        Description: str = ...,
+        RetrievalRoleArn: str = ...,
+        Validators: Sequence["ValidatorTypeDef"] = ...,
+        Tags: Mapping[str, str] = ...
     ) -> ConfigurationProfileTypeDef:
         """
         Information that enables AppConfig to access the configuration source.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.create_configuration_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.create_configuration_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_configuration_profile)
         """
 
@@ -116,16 +116,16 @@ class AppConfigClient(BaseClient):
         DeploymentDurationInMinutes: int,
         GrowthFactor: float,
         ReplicateTo: ReplicateToType,
-        Description: str = None,
-        FinalBakeTimeInMinutes: int = None,
-        GrowthType: GrowthTypeType = None,
-        Tags: Mapping[str, str] = None
+        Description: str = ...,
+        FinalBakeTimeInMinutes: int = ...,
+        GrowthType: GrowthTypeType = ...,
+        Tags: Mapping[str, str] = ...
     ) -> DeploymentStrategyResponseMetadataTypeDef:
         """
         A deployment strategy defines important criteria for rolling out your
         configuration to the designated targets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.create_deployment_strategy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.create_deployment_strategy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_deployment_strategy)
         """
 
@@ -134,14 +134,14 @@ class AppConfigClient(BaseClient):
         *,
         ApplicationId: str,
         Name: str,
-        Description: str = None,
-        Monitors: Sequence["MonitorTypeDef"] = None,
-        Tags: Mapping[str, str] = None
+        Description: str = ...,
+        Monitors: Sequence["MonitorTypeDef"] = ...,
+        Tags: Mapping[str, str] = ...
     ) -> EnvironmentResponseMetadataTypeDef:
         """
         For each application, you define one or more environments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.create_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.create_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_environment)
         """
 
@@ -152,13 +152,13 @@ class AppConfigClient(BaseClient):
         ConfigurationProfileId: str,
         Content: Union[bytes, IO[bytes], StreamingBody],
         ContentType: str,
-        Description: str = None,
-        LatestVersionNumber: int = None
+        Description: str = ...,
+        LatestVersionNumber: int = ...
     ) -> HostedConfigurationVersionTypeDef:
         """
         Create a new configuration in the AppConfig configuration store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.create_hosted_configuration_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.create_hosted_configuration_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_hosted_configuration_version)
         """
 
@@ -166,7 +166,7 @@ class AppConfigClient(BaseClient):
         """
         Delete an application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.delete_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.delete_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_application)
         """
 
@@ -176,7 +176,7 @@ class AppConfigClient(BaseClient):
         """
         Delete a configuration profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.delete_configuration_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.delete_configuration_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_configuration_profile)
         """
 
@@ -184,7 +184,7 @@ class AppConfigClient(BaseClient):
         """
         Delete a deployment strategy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.delete_deployment_strategy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.delete_deployment_strategy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_deployment_strategy)
         """
 
@@ -192,7 +192,7 @@ class AppConfigClient(BaseClient):
         """
         Delete an environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.delete_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.delete_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_environment)
         """
 
@@ -202,21 +202,21 @@ class AppConfigClient(BaseClient):
         """
         Delete a version of a configuration from the AppConfig configuration store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.delete_hosted_configuration_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.delete_hosted_configuration_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_hosted_configuration_version)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#generate_presigned_url)
         """
 
@@ -224,7 +224,7 @@ class AppConfigClient(BaseClient):
         """
         Retrieve information about an application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.get_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.get_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_application)
         """
 
@@ -235,12 +235,12 @@ class AppConfigClient(BaseClient):
         Environment: str,
         Configuration: str,
         ClientId: str,
-        ClientConfigurationVersion: str = None
+        ClientConfigurationVersion: str = ...
     ) -> ConfigurationTypeDef:
         """
         Receive information about a configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.get_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.get_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_configuration)
         """
 
@@ -250,7 +250,7 @@ class AppConfigClient(BaseClient):
         """
         Retrieve information about a configuration profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.get_configuration_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.get_configuration_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_configuration_profile)
         """
 
@@ -260,7 +260,7 @@ class AppConfigClient(BaseClient):
         """
         Retrieve information about a configuration deployment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.get_deployment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.get_deployment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_deployment)
         """
 
@@ -270,7 +270,7 @@ class AppConfigClient(BaseClient):
         """
         Retrieve information about a deployment strategy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.get_deployment_strategy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.get_deployment_strategy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_deployment_strategy)
         """
 
@@ -280,7 +280,7 @@ class AppConfigClient(BaseClient):
         """
         Retrieve information about an environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.get_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.get_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_environment)
         """
 
@@ -290,62 +290,57 @@ class AppConfigClient(BaseClient):
         """
         Get information about a specific configuration version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.get_hosted_configuration_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.get_hosted_configuration_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_hosted_configuration_version)
         """
 
     def list_applications(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ApplicationsTypeDef:
         """
         List all applications in your AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.list_applications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.list_applications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_applications)
         """
 
     def list_configuration_profiles(
-        self, *, ApplicationId: str, MaxResults: int = None, NextToken: str = None
+        self, *, ApplicationId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ConfigurationProfilesTypeDef:
         """
         Lists the configuration profiles for an application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.list_configuration_profiles)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.list_configuration_profiles)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_configuration_profiles)
         """
 
     def list_deployment_strategies(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> DeploymentStrategiesTypeDef:
         """
         List deployment strategies.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.list_deployment_strategies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.list_deployment_strategies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_deployment_strategies)
         """
 
     def list_deployments(
-        self,
-        *,
-        ApplicationId: str,
-        EnvironmentId: str,
-        MaxResults: int = None,
-        NextToken: str = None
+        self, *, ApplicationId: str, EnvironmentId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> DeploymentsTypeDef:
         """
         Lists the deployments for an environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.list_deployments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.list_deployments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_deployments)
         """
 
     def list_environments(
-        self, *, ApplicationId: str, MaxResults: int = None, NextToken: str = None
+        self, *, ApplicationId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> EnvironmentsTypeDef:
         """
         List the environments for an application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.list_environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.list_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_environments)
         """
 
@@ -354,14 +349,14 @@ class AppConfigClient(BaseClient):
         *,
         ApplicationId: str,
         ConfigurationProfileId: str,
-        MaxResults: int = None,
-        NextToken: str = None
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> HostedConfigurationVersionsTypeDef:
         """
         View a list of configurations stored in the AppConfig configuration store by
         version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.list_hosted_configuration_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.list_hosted_configuration_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_hosted_configuration_versions)
         """
 
@@ -369,7 +364,7 @@ class AppConfigClient(BaseClient):
         """
         Retrieves the list of key-value tags assigned to the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_tags_for_resource)
         """
 
@@ -381,13 +376,13 @@ class AppConfigClient(BaseClient):
         DeploymentStrategyId: str,
         ConfigurationProfileId: str,
         ConfigurationVersion: str,
-        Description: str = None,
-        Tags: Mapping[str, str] = None
+        Description: str = ...,
+        Tags: Mapping[str, str] = ...
     ) -> DeploymentTypeDef:
         """
         Starts a deployment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.start_deployment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.start_deployment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#start_deployment)
         """
 
@@ -397,7 +392,7 @@ class AppConfigClient(BaseClient):
         """
         Stops a deployment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.stop_deployment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.stop_deployment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#stop_deployment)
         """
 
@@ -405,7 +400,7 @@ class AppConfigClient(BaseClient):
         """
         Metadata to assign to an AppConfig resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#tag_resource)
         """
 
@@ -413,17 +408,17 @@ class AppConfigClient(BaseClient):
         """
         Deletes a tag key and value from an AppConfig resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#untag_resource)
         """
 
     def update_application(
-        self, *, ApplicationId: str, Name: str = None, Description: str = None
+        self, *, ApplicationId: str, Name: str = ..., Description: str = ...
     ) -> ApplicationResponseMetadataTypeDef:
         """
         Updates an application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.update_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.update_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#update_application)
         """
 
@@ -432,15 +427,15 @@ class AppConfigClient(BaseClient):
         *,
         ApplicationId: str,
         ConfigurationProfileId: str,
-        Name: str = None,
-        Description: str = None,
-        RetrievalRoleArn: str = None,
-        Validators: Sequence["ValidatorTypeDef"] = None
+        Name: str = ...,
+        Description: str = ...,
+        RetrievalRoleArn: str = ...,
+        Validators: Sequence["ValidatorTypeDef"] = ...
     ) -> ConfigurationProfileTypeDef:
         """
         Updates a configuration profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.update_configuration_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.update_configuration_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#update_configuration_profile)
         """
 
@@ -448,16 +443,16 @@ class AppConfigClient(BaseClient):
         self,
         *,
         DeploymentStrategyId: str,
-        Description: str = None,
-        DeploymentDurationInMinutes: int = None,
-        FinalBakeTimeInMinutes: int = None,
-        GrowthFactor: float = None,
-        GrowthType: GrowthTypeType = None
+        Description: str = ...,
+        DeploymentDurationInMinutes: int = ...,
+        FinalBakeTimeInMinutes: int = ...,
+        GrowthFactor: float = ...,
+        GrowthType: GrowthTypeType = ...
     ) -> DeploymentStrategyResponseMetadataTypeDef:
         """
         Updates a deployment strategy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.update_deployment_strategy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.update_deployment_strategy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#update_deployment_strategy)
         """
 
@@ -466,14 +461,14 @@ class AppConfigClient(BaseClient):
         *,
         ApplicationId: str,
         EnvironmentId: str,
-        Name: str = None,
-        Description: str = None,
-        Monitors: Sequence["MonitorTypeDef"] = None
+        Name: str = ...,
+        Description: str = ...,
+        Monitors: Sequence["MonitorTypeDef"] = ...
     ) -> EnvironmentResponseMetadataTypeDef:
         """
         Updates an environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.update_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.update_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#update_environment)
         """
 
@@ -483,6 +478,6 @@ class AppConfigClient(BaseClient):
         """
         Uses the validators in a configuration profile to validate a configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/appconfig.html#AppConfig.Client.validate_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/appconfig.html#AppConfig.Client.validate_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#validate_configuration)
         """
