@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -177,7 +177,7 @@ _OptionalCreateApplicationRequestRequestTypeDef = TypedDict(
     "_OptionalCreateApplicationRequestRequestTypeDef",
     {
         "Description": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -202,8 +202,8 @@ _OptionalCreateConfigurationProfileRequestRequestTypeDef = TypedDict(
     {
         "Description": str,
         "RetrievalRoleArn": str,
-        "Validators": List["ValidatorTypeDef"],
-        "Tags": Dict[str, str],
+        "Validators": Sequence["ValidatorTypeDef"],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -231,7 +231,7 @@ _OptionalCreateDeploymentStrategyRequestRequestTypeDef = TypedDict(
         "Description": str,
         "FinalBakeTimeInMinutes": int,
         "GrowthType": GrowthTypeType,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -255,8 +255,8 @@ _OptionalCreateEnvironmentRequestRequestTypeDef = TypedDict(
     "_OptionalCreateEnvironmentRequestRequestTypeDef",
     {
         "Description": str,
-        "Monitors": List["MonitorTypeDef"],
-        "Tags": Dict[str, str],
+        "Monitors": Sequence["MonitorTypeDef"],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -735,7 +735,7 @@ _OptionalStartDeploymentRequestRequestTypeDef = TypedDict(
     "_OptionalStartDeploymentRequestRequestTypeDef",
     {
         "Description": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -760,7 +760,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -768,7 +768,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -807,7 +807,7 @@ _OptionalUpdateConfigurationProfileRequestRequestTypeDef = TypedDict(
         "Name": str,
         "Description": str,
         "RetrievalRoleArn": str,
-        "Validators": List["ValidatorTypeDef"],
+        "Validators": Sequence["ValidatorTypeDef"],
     },
     total=False,
 )
@@ -858,7 +858,7 @@ _OptionalUpdateEnvironmentRequestRequestTypeDef = TypedDict(
     {
         "Name": str,
         "Description": str,
-        "Monitors": List["MonitorTypeDef"],
+        "Monitors": Sequence["MonitorTypeDef"],
     },
     total=False,
 )
